@@ -1,20 +1,15 @@
-package Class::Load;
-BEGIN {
-  $Class::Load::AUTHORITY = 'cpan:SARTAK';
-}
-# git description: v0.20-8-gc4c6e08
-$Class::Load::VERSION = '0.21';
 use strict;
 use warnings;
+package Class::Load; # git description: v0.22-9-g29ebb54
+# ABSTRACT: A working (require "Class::Name") and more
+# KEYWORDS: class module load require use runtime
+
+our $VERSION = '0.23';
+
 use base 'Exporter';
-use Data::OptList 'mkopt';
+use Data::OptList ();
 use Module::Implementation 0.04;
-use Module::Runtime 0.012 qw(
-    check_module_name
-    module_notional_filename
-    require_module
-    use_module
-);
+use Module::Runtime 0.012 ();
 use Try::Tiny;
 
 {
@@ -48,7 +43,7 @@ sub load_first_existing_class {
         or return;
 
     foreach my $class (@{$classes}) {
-        check_module_name($class->[0]);
+        Module::Runtime::check_module_name($class->[0]);
     }
 
     for my $class (@{$classes}) {
@@ -62,7 +57,7 @@ sub load_first_existing_class {
 
         return $name if $res;
 
-        my $file = module_notional_filename($name);
+        my $file = Module::Runtime::module_notional_filename($name);
 
         next if $e =~ /^Can't locate \Q$file\E in \@INC/;
         next
@@ -97,7 +92,7 @@ sub _version_fail_re {
 sub _nonexistent_fail_re {
     my $name = shift;
 
-    my $file = module_notional_filename($name);
+    my $file = Module::Runtime::module_notional_filename($name);
     return qr/Can't locate \Q$file\E in \@INC/;
 }
 
@@ -118,7 +113,7 @@ sub load_optional_class {
     my $class   = shift;
     my $options = shift;
 
-    check_module_name($class);
+    Module::Runtime::check_module_name($class);
 
     my ($res, $e) = try_load_class($class, $options);
     return 1 if $res;
@@ -138,7 +133,7 @@ sub try_load_class {
     my $class   = shift;
     my $options = shift;
 
-    check_module_name($class);
+    Module::Runtime::check_module_name($class);
 
     local $@;
     undef $ERROR;
@@ -157,7 +152,7 @@ sub try_load_class {
         };
     }
 
-    my $file = module_notional_filename($class);
+    my $file = Module::Runtime::module_notional_filename($class);
     # This says "our diagnostics of the package
     # say perl's INC status about the file being loaded are
     # wrong", so we delete it from %INC, so when we call require(),
@@ -173,10 +168,10 @@ sub try_load_class {
     return try {
         local $SIG{__DIE__} = 'DEFAULT';
         if ($options && defined $options->{-version}) {
-            use_module($class, $options->{-version});
+            Module::Runtime::use_module($class, $options->{-version});
         }
         else {
-            require_module($class);
+            Module::Runtime::require_module($class);
         }
         1;
     }
@@ -204,8 +199,6 @@ sub _croak {
 
 1;
 
-# ABSTRACT: a working (require "Class::Name") and more
-
 __END__
 
 =pod
@@ -214,11 +207,11 @@ __END__
 
 =head1 NAME
 
-Class::Load - a working (require "Class::Name") and more
+Class::Load - A working (require "Class::Name") and more
 
 =head1 VERSION
 
-version 0.21
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -322,6 +315,17 @@ This is useful for using if you want a fallback module system, i.e.:
 That way, if $foo does exist, but can't be loaded due to error, you won't
 get the behaviour of it simply not existing.
 
+=head1 CAVEATS
+
+Because of some of the heuristics that this module uses to infer whether a
+module has been loaded, some false positives may occur in C<is_class_loaded>
+checks (which are also performed internally in other interfaces) -- if a class
+has started to be loaded but then dies, it may appear that it has already been
+loaded, which can cause other things to make the wrong decision.
+L<Module::Runtime> doesn't have this issue, but it also doesn't do some things
+that this module does -- for example gracefully handle packages that have been
+defined inline in the same file as another package.
+
 =head1 SEE ALSO
 
 =over 4
@@ -345,12 +349,52 @@ over its competitors.
 This module was designed to be used anywhere you have
 C<if (eval "require $module"; 1)>, which occurs in many large projects.
 
+=item L<Module::Runtime>
+
+A leaner approach to loading modules
+
 =back
 
 =head1 AUTHOR
 
 Shawn M Moore <sartak at bestpractical.com>
 
+=head1 CONTRIBUTORS
+
+=for stopwords Dave Rolsky Shawn Moore Karen Etheridge M Jesse Luehrs Kent Fredric Caleb Cushing
+
+=over 4
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=item *
+
+Shawn Moore <sartak@bestpractical.com>
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Shawn M Moore <sartak@bestpractical.com>
+
+=item *
+
+Jesse Luehrs <doy@tozt.net>
+
+=item *
+
+Kent Fredric <kentfredric@gmail.com>
+
+=item *
+
+Caleb Cushing <xenoterracide@gmail.com>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2008 by Shawn M Moore.
